<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AccountItem</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="40"/>
        <source>Sync successful</source>
        <translation>Conexão bem-sucedida</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="41"/>
        <source>Network error</source>
        <translation>Erro de rede</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="42"/>
        <source>Server exception</source>
        <translation>Exceção do servidor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="43"/>
        <source>Storage full</source>
        <translation>Armazenamento cheio</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="223"/>
        <source>Local account</source>
        <translation>Conta local</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="225"/>
        <source>Event types</source>
        <translation>Tipos de eventos</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="77"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="90"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="92"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="33"/>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="34"/>
        <source>Tuesday</source>
        <translation>Terça-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="35"/>
        <source>Wednesday</source>
        <translation>Quarta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="36"/>
        <source>Thursday</source>
        <translation>Quinta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="37"/>
        <source>Friday</source>
        <translation>Sexta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="38"/>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="39"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="112"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="113"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="114"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="170"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsview.cpp" line="592"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsItem/cmonthschedulenumitem.cpp" line="80"/>
        <source>%1 more</source>
        <translation>%1 mais</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="51"/>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="209"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="98"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="267"/>
        <source>My Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="308"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="312"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="313"/>
        <source>Edit</source>
        <comment>button</comment>
        <translation>Editar</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cpushbutton.cpp" line="17"/>
        <source>New event type</source>
        <translation>Novo tipo de evento</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="45"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="600"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="896"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="256"/>
        <source>End time must be greater than start time</source>
        <translation>O tempo de término deve ser maior que o tempo de início</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="257"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="481"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="510"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1108"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1397"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1401"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="482"/>
        <source>At time of event</source>
        <translation>No momento do evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="483"/>
        <source>15 minutes before</source>
        <translation>15 minutos antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="484"/>
        <source>30 minutes before</source>
        <translation>30 minutos antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="485"/>
        <source>1 hour before</source>
        <translation>1 hora antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="486"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="512"/>
        <source>1 day before</source>
        <translation>1 dia antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="487"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="513"/>
        <source>2 days before</source>
        <translation>2 dias antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="488"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="514"/>
        <source>1 week before</source>
        <translation>1 semana antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="511"/>
        <source>On start day (9:00 AM)</source>
        <translation>No dia de início (9:00 AM)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="558"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1164"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1165"/>
        <source>time(s)</source>
        <translation>vez(es)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="573"/>
        <source>Enter a name please</source>
        <translation>Insira um nome</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="668"/>
        <source>The name can not only contain whitespaces</source>
        <translation>O nome não pode conter apenas espaços em branco</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="724"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="846"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="729"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="881"/>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="734"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="918"/>
        <source>All Day:</source>
        <translation>Dia Inteiro:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="739"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="984"/>
        <source>Starts:</source>
        <translation>Inicia em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="744"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1025"/>
        <source>Ends:</source>
        <translation>Termina em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="749"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1065"/>
        <source>Remind Me:</source>
        <translation>Lembre-me:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="754"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1097"/>
        <source>Repeat:</source>
        <translation>Repetir:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="759"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1131"/>
        <source>End Repeat:</source>
        <translation>Termina em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="815"/>
        <source>Calendar account:</source>
        <translation>Conta de calendário:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="816"/>
        <source>Calendar account</source>
        <translation>Conta de calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="843"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="885"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="915"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="939"/>
        <source>Time:</source>
        <translation>Horário:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="940"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="947"/>
        <source>Solar</source>
        <translation>Solar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="948"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="981"/>
        <source>Starts</source>
        <translation>Inicia em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1022"/>
        <source>Ends</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1067"/>
        <source>Remind Me</source>
        <translation>Lembre-me</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1094"/>
        <source>Repeat</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1402"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1110"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1403"/>
        <source>Weekdays</source>
        <translation>Dias úteis</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1111"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1404"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1112"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1398"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1405"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1113"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1399"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1406"/>
        <source>Yearly</source>
        <translation>Anualmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1133"/>
        <source>End Repeat</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1144"/>
        <source>After</source>
        <translation>Depois</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
        <source>On</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1215"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1216"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="79"/>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Todas as ocorrências de um evento repetitivo devem ter o mesmo status durante o dia inteiro.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="80"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="97"/>
        <source>Do you want to change all occurrences?</source>
        <translation>Alterar todas as ocorrências?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="81"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="98"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="128"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="147"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="167"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="239"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="269"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="82"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="99"/>
        <source>Change All</source>
        <translation>Alterar Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="96"/>
        <source>You are changing the repeating rule of this event.</source>
        <translation>A regra de repetição deste evento será alterada.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="126"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="145"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="165"/>
        <source>You are deleting an event.</source>
        <translation>Um evento será excluído.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="127"/>
        <source>Are you sure you want to delete this event?</source>
        <translation>Excluir este evento?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="129"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="146"/>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Excluir todas as ocorrências deste evento; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="148"/>
        <source>Delete All</source>
        <translation>Excluir Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="149"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="169"/>
        <source>Delete Only This Event</source>
        <translation>Excluir Apenas Este Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="166"/>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Excluir este evento e todas as suas ocorrências futuras; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="168"/>
        <source>Delete All Future Events</source>
        <translation>Excluir Todos os Eventos Futuros</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="235"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="265"/>
        <source>You are changing a repeating event.</source>
        <translation>Um evento repetido será alterado.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="237"/>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Alterar apenas esta ocorrência do evento; ou todas as ocorrências?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="240"/>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="241"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="271"/>
        <source>Only This Event</source>
        <translation>Apenas Este Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="267"/>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Alterar apenas esta ocorrência do evento; ou esta e todas as ocorrências futuras?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="270"/>
        <source>All Future Events</source>
        <translation>Todos os Eventos Futuros</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="382"/>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>Você selecionou um mês bissexto e será lembrado de acordo com as regras do calendário lunar.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="383"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="42"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="43"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="267"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="645"/>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleview.cpp" line="314"/>
        <source>ALL DAY</source>
        <translation>DIA INTEIRO</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="345"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="346"/>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="347"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="366"/>
        <source>Use System Setting</source>
        <translation>Utilizar a configuração do sistema</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="364"/>
        <source>24-hour clock</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="365"/>
        <source>12-hour clock</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="389"/>
        <source>import ICS file</source>
        <translation>importar arquivo ICS</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
        <source>15 mins</source>
        <translation>15 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
        <source>30 mins</source>
        <translation>30 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
        <source>1 hour</source>
        <translation>1 hora</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
        <source>24 hours</source>
        <translation>24 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
        <source>Sync Now</source>
        <translation>Sincronizar Agora</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="576"/>
        <source>Last sync</source>
        <translation>Última sincronização</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="770"/>
        <source>Please go to the &lt;a href=&apos;/&apos;&gt;Control Center&lt;/a&gt; to change system settings</source>
        <translation>Acesse a &lt;a href=&apos;/&apos;&gt;Central de Controle&lt;/a&gt; para alterar as configurações do sistema</translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="72"/>
        <source>(%1 mins)</source>
        <translation>(%1 minutos)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="74"/>
        <source>(%1 hour)</source>
        <translation>(%1 hora)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="76"/>
        <source>(%1 hours)</source>
        <translation>(%1 horas)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="30"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="42"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="50"/>
        <source>W</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="92"/>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="93"/>
        <source>Search events and festivals</source>
        <translation>Procurar eventos e datas comemorativas</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Sun</source>
        <translation>Dom</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Mon</source>
        <translation>Seg</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Tue</source>
        <translation>Ter</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Wed</source>
        <translation>Qua</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Thu</source>
        <translation>Qui</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Fri</source>
        <translation>Sex</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Sat</source>
        <translation>Sáb</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="89"/>
        <source>Week</source>
        <translation>Semana</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="276"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="268"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="271"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="288"/>
        <source>No event</source>
        <translation>Nenhum evento</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="616"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="63"/>
        <source>Calendar</source>
        <translation>Calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="66"/>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>O Calendário é uma ferramenta que permite agendar e visualizar eventos.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="87"/>
        <source>Calendar</source>
        <translation>Calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="356"/>
        <source>Manage</source>
        <translation>Gerenciar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="363"/>
        <source>Privacy Policy</source>
        <translation>Política de privacidade</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="940"/>
        <source>Syncing...</source>
        <translation>Sincronizando...</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="950"/>
        <source>Sync successful</source>
        <translation>Sincronização bem-sucedida</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="958"/>
        <source>Sync failed, please try later</source>
        <translation>A sincronização falhou, tente novamente mais tarde</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleRemindWidget.cpp" line="174"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation type="vanished">Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation type="vanished">Social</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="vanished">Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Lembre-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Lembre-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="vanished">15 minutos depois</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="vanished">1 hora depois</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="vanished">4 horas depois</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Agendar Lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 às %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Hoje</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="47"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="48"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="49"/>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="737"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="142"/>
        <source>export</source>
        <translation>exportar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="213"/>
        <source>import ICS file</source>
        <translation>importar arquivo ICS</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="401"/>
        <source>You are deleting an event type.</source>
        <translation>Você está a eliminar um tipo de evento.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="402"/>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>Todos os eventos deste tipo serão eliminados e não poderão ser recuperados.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="403"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="404"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="96"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="127"/>
        <source>Manage calendar</source>
        <translation>Gerenciar calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="112"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="131"/>
        <source>Event types</source>
        <translation>Tipos de eventos</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="38"/>
        <source>Account settings</source>
        <translation>Configurações de conta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="42"/>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="53"/>
        <source>Select items to be synced</source>
        <translation>Selecionar itens para sincronizar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="56"/>
        <source>Events</source>
        <translation>Eventos</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="146"/>
        <source>General settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="74"/>
        <source>Sync interval</source>
        <translation>Intervalo de sincronização</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="104"/>
        <source>Calendar account</source>
        <translation>Conta de calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="150"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="152"/>
        <source>First day of week</source>
        <translation>Primeiro dia da semana</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="612"/>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="339"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="95"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="273"/>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="21"/>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="47"/>
        <source>New event type</source>
        <translation>Novo tipo de evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="31"/>
        <source>Edit event type</source>
        <translation>Editar o tipo de evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="43"/>
        <source>Import ICS file</source>
        <translation>Importar arquivo ICS</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="140"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="141"/>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="145"/>
        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
        <translation>Arquivo &lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt;:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="156"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="157"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="205"/>
        <source>The name can not only contain whitespaces</source>
        <translation>O nome não pode ser apenas espaços em branco</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="241"/>
        <source>Enter a name please</source>
        <translation>Insira um nome</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="16"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="17"/>
        <source>Delete event</source>
        <translation>Excluir evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="20"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="21"/>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="22"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="25"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="26"/>
        <source>Select all</source>
        <translation>Selecionar Tudo</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>M</source>
        <translation>M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/timejumpdialog.cpp" line="29"/>
        <source>Go</source>
        <comment>button</comment>
        <translation>Ir</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="48"/>
        <source>Sign In</source>
        <comment>button</comment>
        <translation>Entrar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="49"/>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="925"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="188"/>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="337"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="93"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="230"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="56"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="271"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="262"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="610"/>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Hoje</translation>
    </message>
</context>
</TS>